@@ -51,6 +51,15 @@ impl<'a> Ctx<'a> {
             .statements()
             .filter_map(|stmt| match stmt {
                 ast::Stmt::Item(item) => Some(item),
+                // Macro calls can be both items and expressions. The syntax library always treats
+                // them as expressions here, so we undo that.
+                ast::Stmt::ExprStmt(es) => match es.expr()? {
+                    ast::Expr::MacroCall(call) => {
+                        cov_mark::hit!(macro_call_in_macro_stmts_is_added_to_item_tree);
+                        Some(call.into())
+                    }
+                    _ => None,
+                },
                 _ => None,
             })
             .flat_map(|item| self.lower_mod_item(&item, false))
@@ -674,7 +683,7 @@ impl<'a> Ctx<'a> {
                     default: None,
                     provenance: TypeParamProvenance::TraitSelf,
                 });
-                sm.type_params.insert(self_param_id, Either::Left(trait_def.clone()));
+                sm.type_params.insert(self_param_id, Either::Right(trait_def.clone()));
                 // add super traits as bounds on Self
                 // i.e., trait Foo: Bar is equivalent to trait Foo where Self: Bar
                 let self_param = TypeRef::Path(name![Self].into());
