@@ -329,7 +329,7 @@ pub struct Baz;
 "#,
         expect![[r#"
             crate
-            Baz: t v
+            Baz: t
             foo: t
 
             crate::foo
@@ -816,3 +816,26 @@ fn bar() {}
         "#]],
     );
 }
+
+#[test]
+fn self_imports_only_types() {
+    check(
+        r#"
+//- /main.rs
+mod m {
+    pub macro S() {}
+    pub struct S;
+}
+
+use self::m::S::{self};
+    "#,
+        expect![[r#"
+            crate
+            S: t
+            m: t
+
+            crate::m
+            S: t v m
+        "#]],
+    );
+}
